@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/manifest.tcl,v $
-# $Date: 1998/04/29 11:44:38 $
-# $Revision: 1.18.1.184 $
+# $Date: 1998/06/06 10:33:26 $
+# $Revision: 1.18.1.197 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -46,6 +46,7 @@ array set Manifest [list  \
     [file join gifs noii.gif]			{copy} \
     [file join gifs ii.gif]			{copy} \
     [file join gifs lock.gif]			{copy} \
+    [file join gifs log.gif]			{copy} \
     [file join gifs unlock.gif]			{copy} \
     [file join gifs zlogo.gif]			{copy} \
     [file join help Zircon Windows Info]	{copy} \
@@ -88,6 +89,7 @@ array set Manifest [list  \
     [file join lang catala.tcl]			{copy} \
     [file join lib Channel.tcl]			{copy} \
     [file join lib Chat.tcl]			{copy} \
+    [file join lib Consts.tcl]			{copy} \
     [file join lib Control.tcl]			{copy} \
     [file join lib DALnet.tcl]			{copy} \
     [file join lib Entry.tcl]			{copy} \
@@ -108,6 +110,8 @@ array set Manifest [list  \
     [file join lib Server.tcl]			{copy} \
     [file join lib Service.tcl]			{copy} \
     [file join lib Sound.tcl]			{copy} \
+    [file join lib Split.tcl]			{copy} \
+    [file join lib Tags.tcl]			{copy} \
     [file join lib Topic.tcl]			{copy} \
     [file join lib User.tcl]			{copy} \
     [file join lib Util.tcl]			{copy} \
@@ -216,6 +220,7 @@ array set Manifest [list  \
     [file join samples Netspaces PrizonNet]	{} \
     [file join samples Netspaces RedLatina]	{} \
     [file join samples Netspaces Sandnet]	{} \
+    [file join samples Netspaces SomeNet]	{} \
     [file join samples Netspaces Sorcerynet]	{} \
     [file join samples Netspaces StarChat]	{} \
     [file join samples Netspaces StarLink]	{} \
@@ -241,5 +246,5 @@ array set Manifest [list  \
 set Index "lib [file join plugins Dcc] [file join plugins Sed]"
 #
 set Version 1.18
-set Patchlevel 128
+set Patchlevel 141
 
