@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Classes.tcl,v $
-# $Date: 1998/04/29 11:44:23 $
-# $Revision: 1.18.1.74 $
+# $Date: 1998/05/29 13:05:08 $
+# $Revision: 1.18.1.78 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -31,7 +31,7 @@ class Channel {
     actions	0	{bool}
     buttons	1	{bool}
     closeleave	0	{bool}
-    colour	{}	{list {mirc ctcp2}}
+    colour	{}	{list {mirc ansi ctcp2}}
     crypt	{}	{sedkey}
     key		{}	{key}
     logfile	{}	{file}
@@ -43,7 +43,7 @@ class Channel {
     topics	{}	{texts}
     ops		{}	{users}
     ban		{}	{users}
-    msg		{}	{list {Join Kick Kill Leave Lost Mode Quit Topic}}
+    msg		{}	{list {Join Kick Kill Leave Lost Back Mode Quit Topic}}
     bindings	{}	{special}
     icon	{}	{icon}
     foreground	{}	{colour}
@@ -195,6 +195,7 @@ class Friend {
     menu	1	{bool}
     id		{}	{userhost}
     protect	{}	{list}
+    image	{}	{filename}
 } {
     nick	{}
     lnick	{}
@@ -275,6 +276,7 @@ class Net "
     dcclimit	10	{int {Max. No. of DCCs}}
     maxQueue	50	{int {Outbound Queue Limit}}
     nicksize	9	{int {Max. Nickname Size}}
+    dccblock	2048	{int {DCC Blocksize}}
 " {
     restricted	0
     name	{}
@@ -309,6 +311,7 @@ class Net "
     idle	0
     confChange	{}
     nickwait	0
+    timercount	0
     msgQueue	{}
     msgQLen	0
     msgQTag	{}
