@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Control.tcl,v $
-# $Date: 1998/04/23 13:08:53 $
-# $Revision: 1.18.1.88 $
+# $Date: 1998/06/05 19:34:10 $
+# $Revision: 1.18.1.94 $
 #
 #
 package provide zircon 1.18
@@ -99,7 +99,7 @@ proc addToConf {net} {
     $mn.nets add cascade -label [$net name] -menu $mn.nets.$net
     menu $mn.nets.$net -tearoff 0
     $mn.nets.$net add command -label [trans configure] -command "configWin $net"
-    $mn.nets.$net add command -label {Save Current} -command "saveCurrent $net"
+    $mn.nets.$net add command -label [trans {save current}] -command "saveCurrent $net"
     switch {} [$net helpService] {} default {
 	$ctl.helpFrm.help.menu entryconfigure last -state normal
 	set hm $ctl.helpFrm.help.menu.help
@@ -109,6 +109,20 @@ proc addToConf {net} {
     }
 }
 #
+proc delFromConf {name} {
+    set mn [MainControl].helpFrm.info.menu.conf
+    if {[catch {$mn.nets index $name} indx]} return
+    $mn.nets delete $indx
+}
+#
+proc nickKeys {net win} {
+    foreach y [list exclam quotedbl sterling dollar percent ampersand \
+      asterisk parenleft parenright plus equal notsign acute grave at apostrophe \
+      numbersign asciitilde colon less greater comma period question slash] {
+        catch {bind $win <KeyPress-${y}> break}
+    }
+}
+#
 proc MainControl {} {
     if {![winfo exists .@ctl]} {
 	global zircon zlayout zCtl DEBUG
@@ -120,7 +134,7 @@ proc MainControl {} {
 	grid [set hf [frame $ctl.helpFrm -borderwidth 0]] -sticky ew
 	set om [makeMB $hf.info "Zircon V$zircon(version)"]
 	$om configure -tearoff 0
-	$om add command -label "About Zircon" -command credits
+	$om add command -label [trans {about zircon}] -command credits
 	$om add cascade -label [trans configure] -menu $om.conf
 	$om add separator
 	$om add command -label [trans debug] -command zDBGControl \
@@ -129,11 +143,11 @@ proc MainControl {} {
 	$om add command -label [trans quit] -command leaveZircon \
 	  -accelerator $zircon(meta)-q
 	menu $om.conf -tearoff 0
-	$om.conf add cascade -label {Netspaces} -menu $om.conf.nets
+	$om.conf add cascade -label [trans netspaces] -menu $om.conf.nets
 	menu $om.conf.nets -tearoff 0
-	$om.conf add command -label {Save Current} -command "saveCurrent {}"
-	$om.conf add command -label {Save Layout} -command "saveLayout {}"
-	$om.conf add command -label {Reread rc} -command reread -state disabled
+	$om.conf add command -label [trans {save current}] -command "saveCurrent {}"
+	$om.conf add command -label [trans {save layout}] -command "saveLayout {}"
+	$om.conf add command -label [trans {reread prefs}] -command reread -state disabled
 	foreach x {0 1 2 3} {grid columnconfigure $hf $x -weight 1}
 	netspaceMenu $hf
 	set om [makeMB $hf.help Help]
@@ -164,6 +178,7 @@ proc Control {args} {
 #
     button $ctl.invisible -text [trans invisible] -command "$net toggleFlag invisible"
     $this NNSBuild $ctl Nickname nickname [$net nicks] $net  $ctl.invisible
+    nickKeys $net $ctl.nickname
     if {[$net ircIImode]} { set im $zII } { set im $zNOII }
     button $ctl.ii -command "ntoggleII $net $ctl.ii" -image $im
     set en [$this NNSBuild $ctl IRCName ircname [$net ircnames] $net $ctl.ii]
@@ -342,9 +357,6 @@ proc control_ircItems {this state} {
     }
 }
 #
-set ch29 {&LOCAL &KILLS &NOTICES &ERRORS &CHANNEL &HASH &NUMERICS
-    &SERVERS &SERVICES}
-#
 proc control_add2.9stuff {this} {
     global ch29
     set w [$this window]
@@ -497,11 +509,11 @@ proc control_buildUsers {this net ctl row} {
 			    $mn.dcc add command -label [trans $nn] \
 			      -command "usersDCC $net $nn"
 			}
-			$mn.dcc add cascade -label Auto -menu $mn.dcc.menu
+			$mn.dcc add cascade -label [trans auto] -menu $mn.dcc.menu
 			menu $mn.dcc.menu -tearoff 0
-			$mn.dcc.menu add command -label Users \
+			$mn.dcc.menu add command -label [trans users] \
 			   -command "dccSetAutoUser $net"
-			$mn.dcc.menu add command -label Directory \
+			$mn.dcc.menu add command -label [trans directory] \
 			   -command "dccSetAutoDir $net" -state disabled
 		    }
 		CTCP { addCTCPMenu $net $mn {{}} }
