@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Look.tcl,v $
-# $Date: 1998/02/24 14:42:45 $
-# $Revision: 1.18.1.17 $
+# $Date: 1998/05/21 12:55:27 $
+# $Revision: 1.18.1.18 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -85,20 +85,20 @@ proc InitLook {} {
     dispAd {Initialising look...}
     global Look DLook
     look -channel {^\\+.*$} {.*} {
-	        {{Info {limit create url topic}} {Flags {key mod}}}
+	        {{Info {limit create url topic}} {Flags {key mod log}}}
 	        {{Control {Mode Info Action Users Quit Clear}}}
 	        {Text Users}
 	        Entry
 	    }
     look -channel {^\\&.*$} {.*} {
-	        {{Info {limit create url topic}} {Flags {key mod}}}
+	        {{Info {limit create url topic}} {Flags {key mod log}}}
 	        {{Control {Mode Info Action Users Quit Clear}}}
 	        {Text {Users off}}
 	        Entry
 	    }
     look -channel {.*} {.*} {
 		Topic
-	        {{Info {limit create url topic}} {Flags {key mod}}}
+	        {{Info {limit create url topic}} {Flags {key mod log}}}
 	        {{Control {Mode Info Action Users Quit Clear}}}
 	        {Text Users}
 	        Entry
