@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confChan.tcl,v $
-# $Date: 1998/04/27 15:38:10 $
-# $Revision: 1.18.1.28 $
+# $Date: 1998/05/22 12:53:19 $
+# $Revision: 1.18.1.30 $
 #
 package provide zircon 1.18
 #
@@ -22,26 +22,33 @@ proc selectDefault {net} {
     setCCB $net $defChan($net)
 }
 #
-proc changeChan {net dbl win y} {
-    global selID defChan lbdata
+proc selChan {net win y} {
+    global selID lbdata
     saveChan $net
     set v [lindex $lbdata($win) [set p [$win nearest $y]]]
     switch {} [set chn [lindex $v 1]] {
-	if {$dbl} {
-	    set selID($net) nil
-	    setCCB $net {}
-	    confAddChan $net $win $p
-	} {
-	    incr p -1
-	    confSelClear $win $p
-	    selectDefault $net
-	}
+        global defChan
+	incr p -1
+	set chn $defChan($net)
+    }
+    set selID($net) $chn
+    setCCB $net $chn
+    confSelClear $win $p
+}
+
+proc changeChan {net win y} {
+    global selID defChan lbdata
+    set v [lindex $lbdata($win) [set p [$win nearest $y]]]
+    switch {} [set chn [lindex $v 1]] {
+	set selID($net) nil
+	setCCB $net {}
+	confAddChan $net $win $p
     } default {
 	set selID($net) $chn
 	set cnm [lindex $v 0]
 	setCCB $net $chn
 	confSelClear $win $p
-	if {$dbl && [string compare $selID($net) $defChan($net)]} {
+	switch $selID($net) $defChan($net) {} default {
 	    confDABtns $net
 	    tkwait window [mkEntryBox {} {Edit Channel} \
 	      {Edit the channel name:} [list [list channel $cnm]] \
@@ -54,38 +61,30 @@ proc changeChan {net dbl win y} {
 }
 #
 proc setCCB {net chan args} {
-    global Configure.Channel
-    upvar #0 confB$net confB
+    upvar #0 Configure.Channel cInfo confB$net confB
     set w .@conf$net.f.chld
-    switch {} $chan {
-	foreach wc [winfo children $w.options] {
-	    switch $wc $w.options.msg {} default {$wc conf -state disabled}
+    switch {} $chan { set state disabled } default {
+	upvar #0 new$chan new
+	foreach b [lindex $cInfo(msg) 1] {
+	    set confB($b) [expr {[lsearch $new(msg) $b] < 0}]
 	}
-	foreach i [winfo children $w.values] {$i.entry conf -state disabled}
-	foreach i [winfo children $w.look] {$i conf -state disabled}
-	return
+	foreach x [array names cInfo] {
+	    switch [lindex [lindex $cInfo($x) 0] 0] bool {
+	        $w.options.$x configure -variable new${chan}($x)
+	    } int - file - key {
+	        entrySet $w.values.$x.entry [$chan $x]
+	    }
+        }
+        set v $new(icon)
+        entrySet $w.values.icon1.entry [lindex $v 0]
+        entrySet $w.values.icon2.entry [lindex $v 1]
+	set state normal
     }
     foreach i [winfo children $w.options] {
-	switch $i $w.options.msg {} default {$i conf -state normal}
+	switch $i $w.options.msg {} default {$i conf -state $state}
     }
-    foreach i [winfo children $w.values] {catch {$i.entry conf -state normal}}
-    foreach i [winfo children $w.look] {catch {$i conf -state normal}}
-    upvar #0 new$chan new
-    foreach b [lindex [set Configure.Channel(msg)] 1] {
-	set b [string toupper $b]
-	set lb [string tolower $b]
-	set confB($lb) [expr {[lsearch $new(msg) $b] < 0}]
-    }
-    foreach x [array names Configure.Channel] {
-	switch [lindex [set Configure.Channel($x)] 0] bool {
-	    $w.options.$x configure -variable new${chan}($x)
-	} int - file - key {
-	    entrySet $w.values.$x.entry [$chan $x]
-	}
-    }
-    set v $new(icon)
-    entrySet $w.values.icon1.entry [lindex $v 0]
-    entrySet $w.values.icon2.entry [lindex $v 1]
+    foreach i [winfo children $w.values] {catch {$i.entry conf -state $state}}
+    foreach i {fg bg ft} {catch {$w.options.$i conf -state $state}}
 }
 #
 proc CancelCAC {net win posn args} {
@@ -162,8 +161,8 @@ proc confChannels {net win} {
     bind $wincn.l <Delete> "confDelChan $net %W %y"
     bind $wincn.l <BackSpace> "confDelChan $net %W %y"
     bind $wincn.l <Control-h> "confDelChan $net %W %y"
-    bind $wincn.l <Button-1> "changeChan $net 0 %W %y"
-    bind $wincn.l <Double-Button-1> "changeChan $net 1 %W %y"
+    bind $wincn.l <Button-1> "selChan $net %W %y ; break"
+    bind $wincn.l <Double-Button-1> "changeChan $net %W %y ; break"
     frame $win.options
     set i 0
     set j 0
@@ -177,15 +176,14 @@ proc confChannels {net win} {
 	    if {[incr j] > 2} { set j 0 ; incr i }
 	}
     }
-    label $win.options.msg -text [trans {Show Messages}]
+    label $win.options.msg -text [trans {show messages}]
     grid $win.options.msg - -
     if {$j<= 2} { incr i 2 } { incr i}
     set j 0
     foreach opt [lindex [set Configure.Channel(msg)] 1] {
-	set val [string tolower $opt]
-	checkbutton $win.options.msg$val -text [trans $opt] \
-	  -variable confB${net}($val) -command "doConfButton $net $val"
-	grid $win.options.msg$val -row $i -column $j -sticky w
+	checkbutton $win.options.msg$opt -text [trans $opt] \
+	  -variable confB${net}($opt) -command "doConfButton $net $opt"
+	grid $win.options.msg$opt -row $i -column $j -sticky w
 	if {[incr j] > 2} { set j 0 ; incr i }
     }
     frame $win.values
@@ -197,18 +195,18 @@ proc confChannels {net win} {
 	    grid $win.values.$x -sticky ew
 	}
     }
-    labelEntry 0 $win.values.icon1 {-text Icon -width 12} {} $cd
-    labelEntry 0 $win.values.icon2 {-text {Active Icon} -width 12} {} $cd
-    labelEntry 0 $win.values.logfile {-text {Log File} -width 12} {} $cd
-    labelEntry 0 $win.values.key {-text Key -width 12} {} $cd
+    labelEntry 0 $win.values.icon1 "-text [list [trans icon]] -width 12" {} $cd
+    labelEntry 0 $win.values.icon2 "-text [list [trans {active icon}]] -width 12" {} $cd
+    labelEntry 0 $win.values.logfile "-text [list [trans {log file}]] -width 12" {} $cd
+    labelEntry 0 $win.values.key "-text [list [trans key]] -width 12" {} $cd
     foreach wx "$win.values.icon1 $win.values.icon2 $win.values.logfile $win.values.key" {
 	grid $wx -sticky ew
     }
-    grid [button $win.look.fg -text {Foreground Colour} \
+    grid [button $win.look.fg -text [trans {foreground colour}] \
       -command "confChanFG $net $win"] -sticky ew
-    grid [button $win.look.bg -text {Background Colour} \
+    grid [button $win.look.bg -text [trans {background colour}] \
       -command "confChanBG $net $win"] -sticky ew
-    grid [button $win.look.ft -text {Font} \
+    grid [button $win.look.ft -text [trans font] \
       -command "confChanFt $net $win"] -sticky ew
     grid $win.nels $win.options -rowspan 2 -sticky nsew
     grid $win.values -row 0 -column 2 -sticky nsew
@@ -286,12 +284,12 @@ proc confChanBG {net win} {
 }
 #
 proc saveChan {net} {
-    global selID Configure.Channel
+    global selID
     switch nil $selID($net) return
-    upvar #0 new$selID($net) new
+    upvar #0 new$selID($net) new Configure.Channel cInfo
     set w .@conf$net.f.chld.values
-    foreach x [array names Configure.Channel] {
-	switch [lindex [set Configure.Channel($x)] 0] int - file - key {
+    foreach x [array names cInfo] {
+	switch [lindex $cInfo($x) 0] int - file - key {
 	    set v [$w.$x.entry get]
 	    switch -- $new($x) $v {} default {set new($x) $v}
 	}
@@ -305,9 +303,9 @@ proc doConfButton {net indx} {
     global selID
     switch nil $selID($net) return
     upvar #0 new$selID($net) new confB$net confB
-    set vdx [lsearch $new(msg) [set v [string toupper $indx]]]
+    set vdx [lsearch $new(msg) $indx]
     if {!$confB($indx)} {
-	if {$vdx < 0} { lappend new(msg) $v }
+	if {$vdx < 0} { lappend new(msg) $indx}
     } {
 	if {$vdx >= 0} { listdel new(msg) $vdx }
     }
